Applied Physics Letters - Volume 6, Issue 3
Description: Scitation is the online home of leading journals and conference proceedings from AIP Publishing and AIP Member Societies
Date: 1965/02/01

###### NOTICE:

✖

AIP Publishing manuscript submission and processing system (PXP) is currently unavailable to users in China. We are working to resolve the issue as quickly as possible. We apologize for the inconvenience.

尊敬的中国作者和评审人：AIP Publishing (AIP出版公司)的论文发布系统（PXP）目前遇到一些技术问题。我们将为您尽快解决。因此带来的不便，我们向您表达我们诚挚的歉意！

Thank you for your patience during this process.

1887
Advanced Search Volume/Page Search
Publication:
Applied Physics Letters
Vol: Page:

#

- Overview
- Browse
- About
- News
- Media
- Collections

### Volume 6, Issue 3, 01 February 1965

Show / Hide descriptions

#### Index of content:

- ##### Volume 106 (2015)

- ##### Volume 105 (2014)

- ##### Volume 104 (2014)

- ##### Volume 103 (2013)

- ##### Volume 102 (2013)

- ##### Volume 101 (2012)

- ##### Volume 100 (2012)

- ##### Volume 99 (2011)

- ##### Volume 98 (2011)

- ##### Volume 97 (2010)

- ##### Volume 96 (2010)

- ##### Volume 95 (2009)

- ##### Volume 94 (2009)

- ##### Volume 93 (2008)

- ##### Volume 92 (2008)

- ##### Volume 91 (2007)

- ##### Volume 90 (2007)

- ##### Volume 89 (2006)

- ##### Volume 88 (2006)

- ##### Volume 87 (2005)

- ##### Volume 86 (2005)

- ##### Volume 85 (2004)

- ##### Volume 84 (2004)

- ##### Volume 83 (2003)

- ##### Volume 82 (2003)

- ##### Volume 81 (2002)

- ##### Volume 80 (2002)

- ##### Volume 79 (2001)

- ##### Volume 78 (2001)

- ##### Volume 77 (2000)

- ##### Volume 76 (2000)

- ##### Volume 75 (1999)

- ##### Volume 74 (1999)

- ##### Volume 73 (1998)

- ##### Volume 72 (1998)

- ##### Volume 71 (1997)

- ##### Volume 70 (1997)

- ##### Volume 69 (1996)

- ##### Volume 68 (1996)

- ##### Volume 67 (1995)

- ##### Volume 66 (1995)

- ##### Volume 65 (1994)

- ##### Volume 64 (1994)

- ##### Volume 63 (1993)

- ##### Volume 62 (1993)

- ##### Volume 61 (1992)

- ##### Volume 60 (1992)

- ##### Volume 59 (1991)

- ##### Volume 58 (1991)

- ##### Volume 57 (1990)

- ##### Volume 56 (1990)

- ##### Volume 55 (1989)

- ##### Volume 54 (1989)

- ##### Volume 53 (1988)

- ##### Volume 52 (1988)

- ##### Volume 51 (1987)

- ##### Volume 50 (1987)

- ##### Volume 49 (1986)

- ##### Volume 48 (1986)

- ##### Volume 47 (1985)

- ##### Volume 46 (1985)

- ##### Volume 45 (1984)

- ##### Volume 44 (1984)

- ##### Volume 43 (1983)

- ##### Volume 42 (1983)

- ##### Volume 41 (1982)

- ##### Volume 40 (1982)

- ##### Volume 39 (1981)

- ##### Volume 38 (1981)

- ##### Volume 37 (1980)

- ##### Volume 36 (1980)

- ##### Volume 35 (1979)

- ##### Volume 34 (1979)

- ##### Volume 33 (1978)

- ##### Volume 32 (1978)

- ##### Volume 31 (1977)

- ##### Volume 30 (1977)

- ##### Volume 29 (1976)

- ##### Volume 28 (1976)

- ##### Volume 27 (1975)

- ##### Volume 26 (1975)

- ##### Volume 25 (1974)

- ##### Volume 24 (1974)

- ##### Volume 23 (1973)

- ##### Volume 22 (1973)

- ##### Volume 21 (1972)

- ##### Volume 20 (1972)

- ##### Volume 19 (1971)

- ##### Volume 18 (1971)

- ##### Volume 17 (1970)

- ##### Volume 16 (1970)

- ##### Volume 15 (1969)

- ##### Volume 14 (1969)

- ##### Volume 13 (1968)

- ##### Volume 12 (1968)

- ##### Volume 11 (1967)

- ##### Volume 10 (1967)

- ##### Volume 9 (1966)

- ##### Volume 8 (1966)

- ##### Volume 7 (1965)

- ##### Volume 6 (1965)

- ##### Volume 5 (1964)

- ##### Volume 4 (1964)

- ##### Volume 3 (1963)

- ##### Volume 2 (1963)

- ##### Volume 1 (1962)

- ##### INFRARED LASER ACTION AND LIFETIMES IN ARGON II

  F. A. Horrigan, S. H. Koozekanani and R. A. Paananen
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6, 41 (1965); http://dx.doi.org/10.1063/1.1754155
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### LASER ACTION IN URANYL‐SENSITIZED Nd‐DOPED GLASS

  N. T. Melamed, C. Hirayama and P. W. French
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6, 43 (1965); http://dx.doi.org/10.1063/1.1754156
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### Yb3+–Er3+ GLASS LASER

  E. Snitzer and R. Woodcock
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6, 45 (1965); http://dx.doi.org/10.1063/1.1754157
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### ENERGY TRANSFER IN TRIPLY ACTIVATED GLASSES

  H. W. Gandy, R. J. Ginther and J. F. Weller
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6, 46 (1965); http://dx.doi.org/10.1063/1.1754158
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### STAGE I RECOVERY OF DEFORMED ZIRCONIUM

  M. L. Swanson, A. F. Quenneville and H. Schultz
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6, 49 (1965); http://dx.doi.org/10.1063/1.1754159
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### PROPAGATION OF LONGITUDINAL PLASMA OSCILLATIONS NEAR CYCLOTRON HARMONICS

  By R. S. Harp
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6, 51 (1965); http://dx.doi.org/10.1063/1.1754160
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### AN ANALYTIC FORM OF KU AND ULLMANS EQUATIONS

  By John G. Simmons
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6, 54 (1965); http://dx.doi.org/10.1063/1.1754161
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### A NEW PRINCIPLE FOR THE CONSTRUCTION OF STABILIZED SUPERCONDUCTING COILS

  A. R. Kantrowitz and Z. J. J. Stekly
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6, 56 (1965); http://dx.doi.org/10.1063/1.1754162
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### CATHODOLUMINESCENCE OF THIN FILMS CONTAINING RARE‐EARTH OXIDES

  W. W. Hansen and R. E. Myers
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6, 58 (1965); http://dx.doi.org/10.1063/1.1754163
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### LONGITUDINAL INJECTION‐PLASMA LASER OF InSb

  By Ivars Melngailis
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6, 59 (1965); http://dx.doi.org/10.1063/1.1754164
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

### Most Read This Month

Article
content/aip/journal/apl
Journal
5
3

### Most Cited This Month

- - ##### Organic electroluminescent diodes

    C. W. Tang and S. A. VanSlyke
    Scitation Author Page
    PubMed
    Google Scholar

- - ##### Silicon quantum wire array fabrication by electrochemical and chemical dissolution of wafers

    By L. T. Canham
    Scitation Author Page
    PubMed
    Google Scholar

- - ##### VAPOR‐LIQUID‐SOLID MECHANISM OF SINGLE CRYSTAL GROWTH

    R. S. Wagner and W. C. Ellis
    Scitation Author Page
    PubMed
    Google Scholar

- - ##### Electronic analog of the electro‐optic modulator

    Supriyo Datta and Biswajit Das
    Scitation Author Page
    PubMed
    Google Scholar

- - ##### Two‐layer organic photovoltaic cell

    By C. W. Tang
    Scitation Author Page
    PubMed
    Google Scholar

More Less
This is a required field
Please enter a valid email address

## Oops! This section, does not exist...

Use the links on this page to find existing content.

38d913362403a4a254fa758cb6527ba5 journal.issuezxybnytfddd
Scitation: Applied Physics Letters - Volume 6, Issue 3
http://aip.metastore.ingenta.com/content/aip/journal/apl/6/3
BROWSE_VIEW_TOC

- journal/journal.issue
- aip/apl
- /content/aip/journal/apl/6/3
- apl.aip.org/6/3/Right1,Right2,Right3